---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. 

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment:**
 - OS: 
 - Python package source (PyPi, conda, ...)
 - Versions of Python, Java Development Kit, Python modules

**Additional context**
Add any other context about the problem here.

**Test data and/or script/notebook**
If you have a reproducible example case, including test data or a snippet of code, please attach them to this issue.
